rpaframework-assistant
======================
This library allows creating dynamic dialogs during Robot Framework
executions, which can be used for showing information to users and
requesting input from them. It's a part of `RPA Framework`_.


.. _RPA Framework: https://rpaframework.org
